# -*- coding: utf-8 -*-
"""
    __init__

    Jaconda Python API

    :copyright: (c) 2012 by Openlabs Technologies & Consulting (P) LTD
    :license: BSD, see LICENSE for more details.
"""
from api import Notification
